//+------------------------------------------------------------------+
//|                                                                  |
//|                                              spike_alert.mq4     |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "spike_alert.mq4"


#property indicator_separate_window
#property indicator_buffers 4
#property indicator_color1 Silver         //Histogram
#property indicator_color2 Yellow         //1 atr
#property indicator_color3 Red            //3 atr
#property indicator_color4 Orange         //2 atr


extern int slowATRperiod = 576;            //Period of Red Line
extern int fastATRperiod = 1;             //Period of Histogram
extern double slowATRmultiplier = 3.0;    //Red Line multiplier
extern double medATRmultiplier = 2.0;     //Orange Line Multiplier

//Time Stamp Variables

string TimeStamp = "TimeStamp";           //Time Stamp

//---- buffers
double fastATR[];
double slowATR[];
double multipliedATR[];
double medATR[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {

//---- indicators
   SetIndexStyle(0,DRAW_HISTOGRAM);                //Vertical Lines 
   SetIndexBuffer(0,fastATR);
	SetIndexLabel(0,"fastATR");

   SetIndexStyle(1,DRAW_LINE);                     //Horizontal Yellow Line, 3 ATR
   SetIndexBuffer(1,slowATR);
   SetIndexLabel(1,"slowATR");

   SetIndexStyle (2,DRAW_LINE,STYLE_SOLID,2);      //Horizontal RED Line - ATR
   SetIndexBuffer(2,multipliedATR);
   SetIndexLabel(2,"multipliedATR");

   SetIndexStyle (3,DRAW_LINE,STYLE_SOLID,2);      //Horizonal Orange LIne, 2 ATR
   SetIndexBuffer (3,medATR);
   SetIndexLabel  (3,"MedATR");
       

//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
   {
   //Time Stamp Global Variables  
   
   static datetime Stamp;
   Stamp = GlobalVariableGet(TimeStamp);
   GlobalVariableSet(TimeStamp,Stamp);    
     
     //Indicator calculations----------------------------------
     
     int counted_bars = IndicatorCounted();
   
     int CalculateBars = Bars - counted_bars;
   
   for(int Count = Bars; Count >= 0; Count--)
	  {
  	      fastATR[Count] = iATR(NULL,0,fastATRperiod,Count);                                        //Calculates Histogram     
  	      
  	      slowATR[Count] = iATR(NULL,0,slowATRperiod,Count);                                        //Calculates Yellow Line
  	      
  	      multipliedATR[Count] = ((iATR(NULL,0,slowATRperiod,Count)) * slowATRmultiplier);          //Calculates Red Line
  	      
  	      medATR[Count] = ((iATR(NULL,0,slowATRperiod,Count)) * medATRmultiplier);                   //Calcualtes Orange Line
  	      
	  }



//----------Checking Dollar Strength or Individual Move----------------

//Spike Counter and Proxy variable

   int SpikeCounter;
   bool Spike = false;
   int PriceChangeEUR;

//Defining Price Difference

   double EURBid = MarketInfo("USDCHF",MODE_BID);                 
   double EURClose = iClose("USDCHF",PERIOD_M5,1);


//Checking if Price Change is negative or positive, Using Yen as proxy for Risk assets (note the variables do not reflect the name change)
if(EURBid > EURClose)
   {
   PriceChangeEUR = 1;              //Move up
   }
   else 
      {
       if(EURBid < EURClose)
      {
      PriceChangeEUR = -1;          //Move Down
      }else
         {
         PriceChangeEUR = 0;
         }
      }     

//EUR
   double ATRFastEUR = iATR("EURUSD",PERIOD_M5,fastATRperiod,0);        //mimics histogram
   double ATRSlowEUR = iATR("EURUSD",PERIOD_M5,slowATRperiod,0);        //mmics red line

//GBP
   double ATRFastGBP = iATR("GBPUSD",PERIOD_M5,fastATRperiod,0);        //mimics histogram
   double ATRSlowGBP = iATR("GBPUSD",PERIOD_M5,slowATRperiod,0);        //mmics red line

//AUD
   double ATRFastAUD = iATR("AUDUSD",PERIOD_M5,fastATRperiod,0);        //mimics histogram
   double ATRSlowAUD = iATR("AUDUSD",PERIOD_M5,slowATRperiod,0);        //mmics red line

//NZD
   double ATRFastNZD = iATR("NZDUSD",PERIOD_M5,fastATRperiod,0);        //mimics histogram
   double ATRSlowNZD = iATR("NZDUSD",PERIOD_M5,slowATRperiod,0);        //mmics red line

//CAD
   double ATRFastCAD = iATR("USDCAD",PERIOD_M5,fastATRperiod,0);        //mimics histogram
   double ATRSlowCAD = iATR("USDCAD",PERIOD_M5,slowATRperiod,0);        //mmics red line

//JPY
   double ATRFastJPY = iATR("USDJPY",PERIOD_M5,fastATRperiod,0);        //mimics histogram
   double ATRSlowJPY = iATR("USDJPY",PERIOD_M5,slowATRperiod,0);        //mmics red line

//UCHF
   double ATRFastUCHF = iATR("USDCHF",PERIOD_M5,fastATRperiod,0);        //mimics histogram
   double ATRSlowUCHF = iATR("USDCHF",PERIOD_M5,slowATRperiod,0);        //mmics red line

//ECHF
   double ATRFastECHF = iATR("EURCHF",PERIOD_M5,fastATRperiod,0);        //mimics histogram
   double ATRSlowECHF = iATR("EURCHF",PERIOD_M5,slowATRperiod,0);        //mmics red line

//Local Symbol
   double ATRFastLocal = iATR(NULL,PERIOD_M5,fastATRperiod,0);        //mimics histogram
   double ATRSlowLocal = iATR(NULL,PERIOD_M5,slowATRperiod,0);        //mmics red line

//Counting Spikes

   if(ATRFastLocal >= (ATRSlowLocal * slowATRmultiplier))         //If Local Currency Spikes
      {
      Spike = true;
      
      if(ATRFastEUR >= (ATRSlowEUR * slowATRmultiplier))           //EUR +1
         {
         SpikeCounter++;
         }
         
      if(ATRFastGBP >= (ATRSlowGBP * slowATRmultiplier))       //GBP +1
         {
         SpikeCounter++;
         }
      
      if(ATRFastAUD >= (ATRSlowAUD * slowATRmultiplier))       //AUD +1
         {
         SpikeCounter++;        
         }   
         
      if(ATRFastNZD >= (ATRSlowNZD * slowATRmultiplier))       //NZD +1
         {
         SpikeCounter++;
         }      
         
      if(ATRFastCAD >= (ATRSlowCAD * slowATRmultiplier))       //CAD +1
         {
         SpikeCounter++;
         }      

      if(ATRFastJPY >= (ATRSlowJPY * slowATRmultiplier))       //JPY +1
         {
         SpikeCounter++;
         }   
       
      if(ATRFastUCHF >= (ATRSlowUCHF * slowATRmultiplier))       //CHF +1
         {
         SpikeCounter++;
         }
      
      if(ATRFastECHF >= (ATRSlowECHF * slowATRmultiplier))     //ECHF + 1
         {
         SpikeCounter++;
         }      
               
               
      }                                               
      
   if(Spike == true && Stamp != Time[0])             //if theres a spike and no alert has been issued in past candle then
      {                                                                                                                                
        Alert ("Spike on: ", Symbol());
        Spike = false;                             //reset counter   
                                          
        GlobalVariableSet(TimeStamp,Time[0]);
        Stamp = GlobalVariableGet(TimeStamp);     
            
      }      
        
            
                                              

//Calculation for Comment

   double ATRYellow = iATR(NULL,PERIOD_M5,slowATRperiod,0);           //mimics Yellow line
   double ATRfast = iATR(NULL,PERIOD_M5,fastATRperiod,0);            //mimics histogram
   double CurrentATR = ATRfast / ATRYellow;
   double NormalATR = NormalizeDouble(CurrentATR,2);
   

//Comment Displaying
   
   RefreshRates();
   if(SpikeCounter >= 3 && PriceChangeEUR == 1)          //If we have 3 spikes and dollar rises against CHF Then
      {  
       Comment("Current Volatility is: ", NormalATR," ATR", "\n", "Dollar Strength-Risk Off");               
      }
    
   RefreshRates();  
   if(SpikeCounter >= 3 && PriceChangeEUR == -1)         //If we have 3 spikes and dollar declines against CHF Then
      {
      Comment("Current Volatility is: ", NormalATR," ATR", "\n", "Dollar Weakness-Risk On");            
      }
      
   RefreshRates();
   if(SpikeCounter < 3)                                  //If we have less than 3 spikes Then
      {
      Comment("Current Volatility is: ", NormalATR," ATR");   
      }
         
//----
   return(0);
  }
//+------------------------------------------------------------------+